# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.1.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _medlocalization
else:
    import _medlocalization

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator_medlocalization_module(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medlocalization.delete_SwigPyIterator_medlocalization_module

    def value(self):
        return _medlocalization.SwigPyIterator_medlocalization_module_value(self)

    def incr(self, n=1):
        return _medlocalization.SwigPyIterator_medlocalization_module_incr(self, n)

    def decr(self, n=1):
        return _medlocalization.SwigPyIterator_medlocalization_module_decr(self, n)

    def distance(self, x):
        return _medlocalization.SwigPyIterator_medlocalization_module_distance(self, x)

    def equal(self, x):
        return _medlocalization.SwigPyIterator_medlocalization_module_equal(self, x)

    def copy(self):
        return _medlocalization.SwigPyIterator_medlocalization_module_copy(self)

    def next(self):
        return _medlocalization.SwigPyIterator_medlocalization_module_next(self)

    def __next__(self):
        return _medlocalization.SwigPyIterator_medlocalization_module___next__(self)

    def previous(self):
        return _medlocalization.SwigPyIterator_medlocalization_module_previous(self)

    def advance(self, n):
        return _medlocalization.SwigPyIterator_medlocalization_module_advance(self, n)

    def __eq__(self, x):
        return _medlocalization.SwigPyIterator_medlocalization_module___eq__(self, x)

    def __ne__(self, x):
        return _medlocalization.SwigPyIterator_medlocalization_module___ne__(self, x)

    def __iadd__(self, n):
        return _medlocalization.SwigPyIterator_medlocalization_module___iadd__(self, n)

    def __isub__(self, n):
        return _medlocalization.SwigPyIterator_medlocalization_module___isub__(self, n)

    def __add__(self, n):
        return _medlocalization.SwigPyIterator_medlocalization_module___add__(self, n)

    def __sub__(self, *args):
        return _medlocalization.SwigPyIterator_medlocalization_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self

# Register SwigPyIterator_medlocalization_module in _medlocalization:
_medlocalization.SwigPyIterator_medlocalization_module_swigregister(SwigPyIterator_medlocalization_module)
HAVE_CC_C99 = _medlocalization.HAVE_CC_C99
HAVE_CUSERID = _medlocalization.HAVE_CUSERID
HAVE_DLFCN_H = _medlocalization.HAVE_DLFCN_H
HAVE_FTIME = _medlocalization.HAVE_FTIME
HAVE_GETEUID = _medlocalization.HAVE_GETEUID
HAVE_GETPWUID = _medlocalization.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medlocalization.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medlocalization.HAVE_H5PUBLIC_H
HAVE_INT64 = _medlocalization.HAVE_INT64
HAVE_INTTYPES_H = _medlocalization.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medlocalization.HAVE_MALLOC_H
HAVE_PWD_H = _medlocalization.HAVE_PWD_H
HAVE_STDBOOL_H = _medlocalization.HAVE_STDBOOL_H
HAVE_STDINT_H = _medlocalization.HAVE_STDINT_H
HAVE_STDIO_H = _medlocalization.HAVE_STDIO_H
HAVE_STDLIB_H = _medlocalization.HAVE_STDLIB_H
HAVE_STRINGS_H = _medlocalization.HAVE_STRINGS_H
HAVE_STRING_H = _medlocalization.HAVE_STRING_H
HAVE_SYS_STAT_H = _medlocalization.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medlocalization.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medlocalization.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medlocalization.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medlocalization.HAVE_UNISTD_H
HAVE__BOOL = _medlocalization.HAVE__BOOL
MED_CHECK_23FORMAT = _medlocalization.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medlocalization.MED_HAVE_FORTRAN
MESGERR = _medlocalization.MESGERR
PACKAGE = _medlocalization.PACKAGE
PACKAGE_BUGREPORT = _medlocalization.PACKAGE_BUGREPORT
PACKAGE_NAME = _medlocalization.PACKAGE_NAME
PACKAGE_STRING = _medlocalization.PACKAGE_STRING
PACKAGE_URL = _medlocalization.PACKAGE_URL
PACKAGE_VERSION = _medlocalization.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medlocalization.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medlocalization.SIZEOF_INT
SIZEOF_LONG = _medlocalization.SIZEOF_LONG
STDC_HEADERS = _medlocalization.STDC_HEADERS
VERSION = _medlocalization.VERSION
HDF_VERSION_REF = _medlocalization.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medlocalization.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medlocalization.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medlocalization.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medlocalization.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medlocalization.H5F_LIBVER_18
MED_MAJOR_NUM = _medlocalization.MED_MAJOR_NUM
MED_MINOR_NUM = _medlocalization.MED_MINOR_NUM
MED_RELEASE_NUM = _medlocalization.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medlocalization.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medlocalization.MED_4_LATEST_MINOR
MED_40_LATEST_RELEASE = _medlocalization.MED_40_LATEST_RELEASE
MED_NUM_MAJEUR = _medlocalization.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medlocalization.MED_NUM_MINEUR
MED_NUM_RELEASE = _medlocalization.MED_NUM_RELEASE
MED_VERSION_STR = _medlocalization.MED_VERSION_STR
MED_MAX_PARA = _medlocalization.MED_MAX_PARA
MED_COMMENT_SIZE = _medlocalization.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medlocalization.MED_IDENT_SIZE
MED_NAME_SIZE = _medlocalization.MED_NAME_SIZE
MED_SNAME_SIZE = _medlocalization.MED_SNAME_SIZE
MED_LNAME_SIZE = _medlocalization.MED_LNAME_SIZE
MED_SNAME_BLANK = _medlocalization.MED_SNAME_BLANK
MED_NAME_BLANK = _medlocalization.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medlocalization.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medlocalization.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medlocalization.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medlocalization.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medlocalization.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medlocalization.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medlocalization.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medlocalization.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medlocalization.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medlocalization.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medlocalization.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medlocalization.MED_ACC_RDONLY
MED_ACC_RDWR = _medlocalization.MED_ACC_RDWR
MED_ACC_RDEXT = _medlocalization.MED_ACC_RDEXT
MED_ACC_CREAT = _medlocalization.MED_ACC_CREAT
MED_ACC_UNDEF = _medlocalization.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medlocalization.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medlocalization.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medlocalization.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medlocalization.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medlocalization.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medlocalization.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medlocalization.MED_UNDEF_GRID_TYPE
MED_CELL = _medlocalization.MED_CELL
MED_DESCENDING_FACE = _medlocalization.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medlocalization.MED_DESCENDING_EDGE
MED_NODE = _medlocalization.MED_NODE
MED_NODE_ELEMENT = _medlocalization.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medlocalization.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medlocalization.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medlocalization.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medlocalization.MED_N_ENTITY_TYPES
MED_COORDINATE = _medlocalization.MED_COORDINATE
MED_CONNECTIVITY = _medlocalization.MED_CONNECTIVITY
MED_NAME = _medlocalization.MED_NAME
MED_NUMBER = _medlocalization.MED_NUMBER
MED_FAMILY_NUMBER = _medlocalization.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medlocalization.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medlocalization.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medlocalization.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medlocalization.MED_INDEX_FACE
MED_INDEX_NODE = _medlocalization.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medlocalization.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medlocalization.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medlocalization.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medlocalization.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medlocalization.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medlocalization.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medlocalization.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medlocalization.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medlocalization.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medlocalization.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medlocalization.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medlocalization.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medlocalization.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medlocalization.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medlocalization.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medlocalization.MED_INTERNAL_UNDEF
MED_DOUBLE = _medlocalization.MED_DOUBLE
MED_FLOAT64 = _medlocalization.MED_FLOAT64
MED_FLOAT32 = _medlocalization.MED_FLOAT32
MED_INT32 = _medlocalization.MED_INT32
MED_INT64 = _medlocalization.MED_INT64
MED_INT = _medlocalization.MED_INT
MED_ATT_FLOAT64 = _medlocalization.MED_ATT_FLOAT64
MED_ATT_INT = _medlocalization.MED_ATT_INT
MED_ATT_NAME = _medlocalization.MED_ATT_NAME
MED_ATT_UNDEF = _medlocalization.MED_ATT_UNDEF
MED_MESH = _medlocalization.MED_MESH
MED_FIELD = _medlocalization.MED_FIELD
MED_LIBRARY = _medlocalization.MED_LIBRARY
MED_FILE = _medlocalization.MED_FILE
MED_MESH_SUPPORT = _medlocalization.MED_MESH_SUPPORT
MED_ELSTRUCT = _medlocalization.MED_ELSTRUCT
MED_FAMILY = _medlocalization.MED_FAMILY
MED_EQUIVALENCE = _medlocalization.MED_EQUIVALENCE
MED_GROUP = _medlocalization.MED_GROUP
MED_JOINT = _medlocalization.MED_JOINT
MED_LOCALIZATION = _medlocalization.MED_LOCALIZATION
MED_PROFILE = _medlocalization.MED_PROFILE
MED_FILTER = _medlocalization.MED_FILTER
MED_INTERPOLATION = _medlocalization.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medlocalization.MED_NUMERICAL_DATA
MED_LINK = _medlocalization.MED_LINK
MED_CLASS_UNDEF = _medlocalization.MED_CLASS_UNDEF
MED_CLASS_ALL = _medlocalization.MED_CLASS_ALL
MED_POINT1 = _medlocalization.MED_POINT1
MED_SEG2 = _medlocalization.MED_SEG2
MED_SEG3 = _medlocalization.MED_SEG3
MED_SEG4 = _medlocalization.MED_SEG4
MED_TRIA3 = _medlocalization.MED_TRIA3
MED_QUAD4 = _medlocalization.MED_QUAD4
MED_TRIA6 = _medlocalization.MED_TRIA6
MED_TRIA7 = _medlocalization.MED_TRIA7
MED_QUAD8 = _medlocalization.MED_QUAD8
MED_QUAD9 = _medlocalization.MED_QUAD9
MED_TETRA4 = _medlocalization.MED_TETRA4
MED_PYRA5 = _medlocalization.MED_PYRA5
MED_PENTA6 = _medlocalization.MED_PENTA6
MED_HEXA8 = _medlocalization.MED_HEXA8
MED_TETRA10 = _medlocalization.MED_TETRA10
MED_OCTA12 = _medlocalization.MED_OCTA12
MED_PYRA13 = _medlocalization.MED_PYRA13
MED_PENTA15 = _medlocalization.MED_PENTA15
MED_PENTA18 = _medlocalization.MED_PENTA18
MED_HEXA20 = _medlocalization.MED_HEXA20
MED_HEXA27 = _medlocalization.MED_HEXA27
MED_POLYGON = _medlocalization.MED_POLYGON
MED_POLYGON2 = _medlocalization.MED_POLYGON2
MED_POLYHEDRON = _medlocalization.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medlocalization.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medlocalization.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medlocalization.MED_NONE
MED_NO_GEOTYPE = _medlocalization.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medlocalization.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medlocalization.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medlocalization.MED_ALL_GEOTYPE
MED_GEO_ALL = _medlocalization.MED_GEO_ALL
MED_N_CELL_GEO = _medlocalization.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medlocalization.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medlocalization.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medlocalization.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medlocalization.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medlocalization.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medlocalization.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medlocalization.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medlocalization.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medlocalization.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medlocalization.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medlocalization.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medlocalization.MED_NODAL
MED_DESCENDING = _medlocalization.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medlocalization.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medlocalization.MED_NO_CMODE
MED_CARTESIAN = _medlocalization.MED_CARTESIAN
MED_CYLINDRICAL = _medlocalization.MED_CYLINDRICAL
MED_SPHERICAL = _medlocalization.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medlocalization.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medlocalization.MED_FALSE
MED_TRUE = _medlocalization.MED_TRUE
MED_GAUSS_ELNO = _medlocalization.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medlocalization.MED_IPOINT_ELNO
MED_NO_NAME = _medlocalization.MED_NO_NAME
MED_NO_MESHNAME = _medlocalization.MED_NO_MESHNAME
MED_NO_MESH = _medlocalization.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medlocalization.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medlocalization.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medlocalization.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medlocalization.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medlocalization.MED_NO_PROFILE
MED_NO_GROUP = _medlocalization.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medlocalization.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medlocalization.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medlocalization.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medlocalization.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medlocalization.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medlocalization.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medlocalization.MED_SORT_DTIT
MED_SORT_ITDT = _medlocalization.MED_SORT_ITDT
MED_SORT_UNDEF = _medlocalization.MED_SORT_UNDEF
MED_ALL_DT = _medlocalization.MED_ALL_DT
MED_ALL_IT = _medlocalization.MED_ALL_IT
MED_NO_DT = _medlocalization.MED_NO_DT
MED_NO_IT = _medlocalization.MED_NO_IT
MED_UNDEF_DT = _medlocalization.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medlocalization.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medlocalization.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medlocalization.med_filter_nspaces_get, _medlocalization.med_filter_nspaces_set)
    memspace = property(_medlocalization.med_filter_memspace_get, _medlocalization.med_filter_memspace_set)
    diskspace = property(_medlocalization.med_filter_diskspace_get, _medlocalization.med_filter_diskspace_set)
    nentity = property(_medlocalization.med_filter_nentity_get, _medlocalization.med_filter_nentity_set)
    nvaluesperentity = property(_medlocalization.med_filter_nvaluesperentity_get, _medlocalization.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medlocalization.med_filter_nconstituentpervalue_get, _medlocalization.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medlocalization.med_filter_constituentselect_get, _medlocalization.med_filter_constituentselect_set)
    switchmode = property(_medlocalization.med_filter_switchmode_get, _medlocalization.med_filter_switchmode_set)
    filterarraysize = property(_medlocalization.med_filter_filterarraysize_get, _medlocalization.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medlocalization.med_filter_filterarray23v30_get, _medlocalization.med_filter_filterarray23v30_set)
    profilearraysize = property(_medlocalization.med_filter_profilearraysize_get, _medlocalization.med_filter_profilearraysize_set)
    storagemode = property(_medlocalization.med_filter_storagemode_get, _medlocalization.med_filter_storagemode_set)
    profilename = property(_medlocalization.med_filter_profilename_get, _medlocalization.med_filter_profilename_set)

    def __init__(self):
        r"""__init__(self) -> med_filter"""
        _medlocalization.med_filter_swiginit(self, _medlocalization.new_med_filter())
    __swig_destroy__ = _medlocalization.delete_med_filter

# Register med_filter in _medlocalization:
_medlocalization.med_filter_swigregister(med_filter)
MED_NO_FILTER_SIZE = _medlocalization.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medlocalization.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medlocalization.med_file_version_majeur_get, _medlocalization.med_file_version_majeur_set)
    mineur = property(_medlocalization.med_file_version_mineur_get, _medlocalization.med_file_version_mineur_set)
    release = property(_medlocalization.med_file_version_release_get, _medlocalization.med_file_version_release_set)

    def __init__(self):
        r"""__init__(self) -> med_file_version"""
        _medlocalization.med_file_version_swiginit(self, _medlocalization.new_med_file_version())
    __swig_destroy__ = _medlocalization.delete_med_file_version

# Register med_file_version in _medlocalization:
_medlocalization.med_file_version_swigregister(med_file_version)
class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medlocalization.med_memfile_app_image_ptr_get, _medlocalization.med_memfile_app_image_ptr_set)
    app_image_size = property(_medlocalization.med_memfile_app_image_size_get, _medlocalization.med_memfile_app_image_size_set)
    ref_count = property(_medlocalization.med_memfile_ref_count_get, _medlocalization.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medlocalization.med_memfile_fapl_image_ptr_get, _medlocalization.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medlocalization.med_memfile_fapl_image_size_get, _medlocalization.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medlocalization.med_memfile_fapl_ref_count_get, _medlocalization.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medlocalization.med_memfile_vfd_image_ptr_get, _medlocalization.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medlocalization.med_memfile_vfd_image_size_get, _medlocalization.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medlocalization.med_memfile_vfd_ref_count_get, _medlocalization.med_memfile_vfd_ref_count_set)
    flags = property(_medlocalization.med_memfile_flags_get, _medlocalization.med_memfile_flags_set)

    def __init__(self):
        r"""__init__(self) -> med_memfile"""
        _medlocalization.med_memfile_swiginit(self, _medlocalization.new_med_memfile())
    __swig_destroy__ = _medlocalization.delete_med_memfile

# Register med_memfile in _medlocalization:
_medlocalization.med_memfile_swigregister(med_memfile)

def MEDgetEntityTypeIt(entitytype):
    return _medlocalization.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medlocalization.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medlocalization.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medlocalization.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medlocalization.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medlocalization.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medlocalization.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medlocalization.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medlocalization.MED_PARTICLE_NAME
MED_BALL_NAME = _medlocalization.MED_BALL_NAME
MED_BEAM_NAME = _medlocalization.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medlocalization.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medlocalization.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medlocalization.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlocalization.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlocalization.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medlocalization.MEDBOOL___bool__(self)

    def __len__(self):
        return _medlocalization.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medlocalization.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlocalization.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlocalization.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlocalization.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlocalization.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlocalization.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medlocalization.MEDBOOL_pop(self)

    def append(self, x):
        return _medlocalization.MEDBOOL_append(self, x)

    def empty(self):
        return _medlocalization.MEDBOOL_empty(self)

    def size(self):
        return _medlocalization.MEDBOOL_size(self)

    def swap(self, v):
        return _medlocalization.MEDBOOL_swap(self, v)

    def begin(self):
        return _medlocalization.MEDBOOL_begin(self)

    def end(self):
        return _medlocalization.MEDBOOL_end(self)

    def rbegin(self):
        return _medlocalization.MEDBOOL_rbegin(self)

    def rend(self):
        return _medlocalization.MEDBOOL_rend(self)

    def clear(self):
        return _medlocalization.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medlocalization.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medlocalization.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medlocalization.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        _medlocalization.MEDBOOL_swiginit(self, _medlocalization.new_MEDBOOL(*args))

    def push_back(self, x):
        return _medlocalization.MEDBOOL_push_back(self, x)

    def front(self):
        return _medlocalization.MEDBOOL_front(self)

    def back(self):
        return _medlocalization.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medlocalization.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medlocalization.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medlocalization.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medlocalization.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medlocalization.MEDBOOL_capacity(self)
    __swig_destroy__ = _medlocalization.delete_MEDBOOL

# Register MEDBOOL in _medlocalization:
_medlocalization.MEDBOOL_swigregister(MEDBOOL)
cvar = _medlocalization.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlocalization.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlocalization.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medlocalization.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medlocalization.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medlocalization.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlocalization.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlocalization.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlocalization.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlocalization.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlocalization.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medlocalization.MEDFLOAT_pop(self)

    def append(self, x):
        return _medlocalization.MEDFLOAT_append(self, x)

    def empty(self):
        return _medlocalization.MEDFLOAT_empty(self)

    def size(self):
        return _medlocalization.MEDFLOAT_size(self)

    def swap(self, v):
        return _medlocalization.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medlocalization.MEDFLOAT_begin(self)

    def end(self):
        return _medlocalization.MEDFLOAT_end(self)

    def rbegin(self):
        return _medlocalization.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medlocalization.MEDFLOAT_rend(self)

    def clear(self):
        return _medlocalization.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medlocalization.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medlocalization.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medlocalization.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        _medlocalization.MEDFLOAT_swiginit(self, _medlocalization.new_MEDFLOAT(*args))

    def push_back(self, x):
        return _medlocalization.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medlocalization.MEDFLOAT_front(self)

    def back(self):
        return _medlocalization.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medlocalization.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medlocalization.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medlocalization.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medlocalization.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medlocalization.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medlocalization.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medlocalization.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medlocalization.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medlocalization.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medlocalization.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medlocalization.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medlocalization.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medlocalization.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medlocalization.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medlocalization.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medlocalization.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medlocalization.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medlocalization.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medlocalization.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medlocalization.delete_MEDFLOAT

# Register MEDFLOAT in _medlocalization:
_medlocalization.MEDFLOAT_swigregister(MEDFLOAT)

MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlocalization.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlocalization.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medlocalization.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medlocalization.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medlocalization.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlocalization.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlocalization.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlocalization.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlocalization.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlocalization.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medlocalization.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medlocalization.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medlocalization.MEDFLOAT32_empty(self)

    def size(self):
        return _medlocalization.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medlocalization.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medlocalization.MEDFLOAT32_begin(self)

    def end(self):
        return _medlocalization.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medlocalization.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medlocalization.MEDFLOAT32_rend(self)

    def clear(self):
        return _medlocalization.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medlocalization.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medlocalization.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medlocalization.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        _medlocalization.MEDFLOAT32_swiginit(self, _medlocalization.new_MEDFLOAT32(*args))

    def push_back(self, x):
        return _medlocalization.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medlocalization.MEDFLOAT32_front(self)

    def back(self):
        return _medlocalization.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medlocalization.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medlocalization.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medlocalization.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medlocalization.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medlocalization.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medlocalization.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medlocalization.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medlocalization.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medlocalization.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medlocalization.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medlocalization.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medlocalization.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medlocalization.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medlocalization.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medlocalization.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medlocalization.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medlocalization.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medlocalization.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medlocalization.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medlocalization.delete_MEDFLOAT32

# Register MEDFLOAT32 in _medlocalization:
_medlocalization.MEDFLOAT32_swigregister(MEDFLOAT32)

MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlocalization.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlocalization.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medlocalization.MEDINT___bool__(self)

    def __len__(self):
        return _medlocalization.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medlocalization.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlocalization.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlocalization.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlocalization.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlocalization.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlocalization.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medlocalization.MEDINT_pop(self)

    def append(self, x):
        return _medlocalization.MEDINT_append(self, x)

    def empty(self):
        return _medlocalization.MEDINT_empty(self)

    def size(self):
        return _medlocalization.MEDINT_size(self)

    def swap(self, v):
        return _medlocalization.MEDINT_swap(self, v)

    def begin(self):
        return _medlocalization.MEDINT_begin(self)

    def end(self):
        return _medlocalization.MEDINT_end(self)

    def rbegin(self):
        return _medlocalization.MEDINT_rbegin(self)

    def rend(self):
        return _medlocalization.MEDINT_rend(self)

    def clear(self):
        return _medlocalization.MEDINT_clear(self)

    def get_allocator(self):
        return _medlocalization.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medlocalization.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medlocalization.MEDINT_erase(self, *args)

    def __init__(self, *args):
        _medlocalization.MEDINT_swiginit(self, _medlocalization.new_MEDINT(*args))

    def push_back(self, x):
        return _medlocalization.MEDINT_push_back(self, x)

    def front(self):
        return _medlocalization.MEDINT_front(self)

    def back(self):
        return _medlocalization.MEDINT_back(self)

    def assign(self, n, x):
        return _medlocalization.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medlocalization.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medlocalization.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medlocalization.MEDINT_reserve(self, n)

    def capacity(self):
        return _medlocalization.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medlocalization.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medlocalization.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medlocalization.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medlocalization.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medlocalization.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medlocalization.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medlocalization.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medlocalization.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medlocalization.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medlocalization.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medlocalization.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medlocalization.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medlocalization.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medlocalization.MEDINT___ne__(self, value)
    __swig_destroy__ = _medlocalization.delete_MEDINT

# Register MEDINT in _medlocalization:
_medlocalization.MEDINT_swigregister(MEDINT)

MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medlocalization.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medlocalization.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medlocalization.MEDCHAR___bool__(self)

    def __len__(self):
        return _medlocalization.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medlocalization.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medlocalization.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medlocalization.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medlocalization.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medlocalization.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medlocalization.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medlocalization.MEDCHAR_pop(self)

    def append(self, x):
        return _medlocalization.MEDCHAR_append(self, x)

    def empty(self):
        return _medlocalization.MEDCHAR_empty(self)

    def size(self):
        return _medlocalization.MEDCHAR_size(self)

    def swap(self, v):
        return _medlocalization.MEDCHAR_swap(self, v)

    def begin(self):
        return _medlocalization.MEDCHAR_begin(self)

    def end(self):
        return _medlocalization.MEDCHAR_end(self)

    def rbegin(self):
        return _medlocalization.MEDCHAR_rbegin(self)

    def rend(self):
        return _medlocalization.MEDCHAR_rend(self)

    def clear(self):
        return _medlocalization.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medlocalization.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medlocalization.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medlocalization.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        _medlocalization.MEDCHAR_swiginit(self, _medlocalization.new_MEDCHAR(*args))

    def push_back(self, x):
        return _medlocalization.MEDCHAR_push_back(self, x)

    def front(self):
        return _medlocalization.MEDCHAR_front(self)

    def back(self):
        return _medlocalization.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medlocalization.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medlocalization.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medlocalization.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medlocalization.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medlocalization.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medlocalization.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medlocalization.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medlocalization.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medlocalization.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medlocalization.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medlocalization.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medlocalization.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medlocalization.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medlocalization.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medlocalization.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medlocalization.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medlocalization.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medlocalization.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medlocalization.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medlocalization.delete_MEDCHAR

# Register MEDCHAR in _medlocalization:
_medlocalization.MEDCHAR_swigregister(MEDCHAR)

MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDlocalizationWr(fid, localizationname, geotype, spacedimension, elementcoordinate, switchmode, nipoint, ipointcoordinate, weight, geointerpname, ipointstructmeshname):
    r"""
    MEDlocalizationWr(fid, localizationname, geotype, spacedimension, elementcoordinate, switchmode, nipoint, ipointcoordinate, weight, geointerpname, ipointstructmeshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    localizationname: char const *const
    geotype: med_geometry_type const
    spacedimension: med_int const
    elementcoordinate: med_float const *const
    switchmode: enum med_switch_mode const
    nipoint: med_int const
    ipointcoordinate: med_float const *const
    weight: med_float const *const
    geointerpname: char const *const
    ipointstructmeshname: char const *const

    """
    return _medlocalization.MEDlocalizationWr(fid, localizationname, geotype, spacedimension, elementcoordinate, switchmode, nipoint, ipointcoordinate, weight, geointerpname, ipointstructmeshname)

def MEDlocalizationRd(fid, localizationname, switchmode, elementcoordinate, ipointcoordinate, weight):
    r"""
    MEDlocalizationRd(fid, localizationname, switchmode, elementcoordinate, ipointcoordinate, weight) -> med_err

    Parameters
    ----------
    fid: med_idt const
    localizationname: char const *const
    switchmode: enum med_switch_mode const
    elementcoordinate: med_float *const
    ipointcoordinate: med_float *const
    weight: med_float *const

    """
    return _medlocalization.MEDlocalizationRd(fid, localizationname, switchmode, elementcoordinate, ipointcoordinate, weight)

def MEDnLocalization(fid):
    r"""
    MEDnLocalization(fid) -> med_int

    Parameters
    ----------
    fid: med_idt const

    """
    return _medlocalization.MEDnLocalization(fid)

def MEDlocalizationInfo(fid, localizationit):
    r"""
    MEDlocalizationInfo(fid, localizationit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    localizationit: int const

    """
    return _medlocalization.MEDlocalizationInfo(fid, localizationit)

def MEDlocalizationInfoByName(fid, localizationname):
    r"""
    MEDlocalizationInfoByName(fid, localizationname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    localizationname: char const *const

    """
    return _medlocalization.MEDlocalizationInfoByName(fid, localizationname)

